==> zio-aws-proton_2.13-5.17.130.7-sources.jar: zio/aws/proton/model/ListEnvironmentOutputsResponse.scala <==
package zio.aws.proton.model
import zio.aws.proton.model.primitives.EmptyNextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListEnvironmentOutputsResponse(
    nextToken: Option[EmptyNextToken] = None,
    outputs: Iterable[zio.aws.proton.model.Output]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse = {
    import ListEnvironmentOutputsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => EmptyNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .outputs(outputs.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.proton.model.ListEnvironmentOutputsResponse.ReadOnly =
    zio.aws.proton.model.ListEnvironmentOutputsResponse.wrap(buildAwsValue())
}
object ListEnvironmentOutputsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.proton.model.ListEnvironmentOutputsResponse =
      zio.aws.proton.model.ListEnvironmentOutputsResponse(
        nextToken.map(value => value),
        outputs.map { item =>
          item.asEditable
        }
      )
    def nextToken: Option[EmptyNextToken]
    def outputs: List[zio.aws.proton.model.Output.ReadOnly]
    def getNextToken: ZIO[Any, AwsError, EmptyNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getOutputs
        : ZIO[Any, Nothing, List[zio.aws.proton.model.Output.ReadOnly]] =
      ZIO.succeed(outputs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
  ) extends zio.aws.proton.model.ListEnvironmentOutputsResponse.ReadOnly {
    override val nextToken: Option[EmptyNextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.proton.model.primitives.EmptyNextToken(value))
    override val outputs: List[zio.aws.proton.model.Output.ReadOnly] = impl
      .outputs()
      .asScala
      .map { item =>
        zio.aws.proton.model.Output.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
  ): zio.aws.proton.model.ListEnvironmentOutputsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-proton_2.13-7.21.15.11-sources.jar: zio/aws/proton/model/ListEnvironmentOutputsResponse.scala <==
package zio.aws.proton.model
import zio.aws.proton.model.primitives.EmptyNextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListEnvironmentOutputsResponse(
    nextToken: Optional[EmptyNextToken] = Optional.Absent,
    outputs: Iterable[zio.aws.proton.model.Output]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse = {
    import ListEnvironmentOutputsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => EmptyNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .outputs(outputs.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.proton.model.ListEnvironmentOutputsResponse.ReadOnly =
    zio.aws.proton.model.ListEnvironmentOutputsResponse.wrap(buildAwsValue())
}
object ListEnvironmentOutputsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.proton.model.ListEnvironmentOutputsResponse =
      zio.aws.proton.model.ListEnvironmentOutputsResponse(
        nextToken.map(value => value),
        outputs.map { item =>
          item.asEditable
        }
      )
    def nextToken: Optional[EmptyNextToken]
    def outputs: List[zio.aws.proton.model.Output.ReadOnly]
    def getNextToken: ZIO[Any, AwsError, EmptyNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getOutputs
        : ZIO[Any, Nothing, List[zio.aws.proton.model.Output.ReadOnly]] =
      ZIO.succeed(outputs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
  ) extends zio.aws.proton.model.ListEnvironmentOutputsResponse.ReadOnly {
    override val nextToken: Optional[EmptyNextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.proton.model.primitives.EmptyNextToken(value))
    override val outputs: List[zio.aws.proton.model.Output.ReadOnly] = impl
      .outputs()
      .asScala
      .map { item =>
        zio.aws.proton.model.Output.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentOutputsResponse
  ): zio.aws.proton.model.ListEnvironmentOutputsResponse.ReadOnly = new Wrapper(
    impl
  )
}
